! This is the third party lib "GW_UTILS.bas" [version 1.4]
! http://laughton.com/basic/programs/html/GW%20(GUI-Web%20lib)/
!
! It includes misc utility functions for the GW Library.
!
! This lib requires the main lib "GW.bas" and of course Android RFO-BASIC!
! To download the lib when you have "GW.bas" on your device, do:
!    GW_DOWNLOAD_THIRD_PARTY("GW_UTILS.bas")
!
! USAGE: in your program do: INCLUDE "GW_UTILS.bas"
! Then call:
!
!      res = GW_COPY_TO_SD (file_path$) % Checks if file with path file_path$ is in /data.
!                                       % If not and this is an APK, copies it there from assets.
!                                       % Can be used for both GW-related and non-GW files.
!        :res = 1 -> success
!        :res = 0 -> failure
!
!      height = GW_GET_WINDOW_HEIGHT () % get window height (scroll bar excluded)
!
!      width = GW_GET_WINDOW_WIDTH () % get window width (scroll bar excluded)
!
!      GW_MODIFY_VIEWPORT (mypage, "param1=value1 param2=value2 ...") % Modify viewport for page
!        :PARAM           :VALUES
!        :width           :device-width|1 .. 10000
!        :height          :device-height|1 .. 10000
!        :initial-scale   :0.1 .. 10
!        :minimum-scale   :0.1 .. 10
!        :maximum-scale   :0.1 .. 10
!        :user-scalable   :yes|no
!        NOTE: Default Viewport is:
!              width=device-width initial-scale=1 minimum-scale=1 maximum-scale=1 user-scalable=no
!
!      GW_PAGE_SCALE (mypage, zoom) % Change page scaling -- zoom = 0.1 .. 1

INCLUDE "GW.bas"

FN.DEF GW_COPY_TO_SD(f$)
  ! This function is a slight adaptation of MAKE_SURE_IS_ON_SD() in "GW.bas".
  ! It doesn't print on the console and checks if IS_APK before copying.
  FILE.EXISTS onSd, f$
  IF !onSd
    IF !IS_APK() THEN FN.RTN 0
    BYTE.OPEN r, fid, f$
    IF fid<0 THEN FN.RTN 0
    j = IS_IN("/", f$)
    WHILE j
      FILE.MKDIR LEFT$(f$, j)
      j = IS_IN("/", f$, j+1)
    REPEAT
    BYTE.COPY fid, f$
    BYTE.CLOSE fid
  ENDIF
  FN.RTN 1
FN.END

FN.DEF GW_GET_WINDOW_HEIGHT()
  script$ = "RFO(document.documentElement.clientHeight)"
  JS(script$)
  e$ = GW_WAIT_ACTION$()
  IF IS_NUMBER(e$) THEN FN.RTN VAL(e$) ELSE FN.RTN 0
FN.END

FN.DEF GW_GET_WINDOW_WIDTH()
  script$ = "RFO(document.documentElement.clientWidth)"
  JS(script$)
  e$ = GW_WAIT_ACTION$()
  IF IS_NUMBER(e$) THEN FN.RTN VAL(e$) ELSE FN.RTN 0
FN.END

FN.DEF GW_MODIFY_VIEWPORT(page, new_viewport$)
  IF !IS_IN(",", new_viewport$) THEN new_viewport$ = REPLACE$(new_viewport$, " ", ", ")
  page$ = GW_PAGE$(page)
  left = IS_IN("content='", page$) + 8
  right = LEN(page$) - IS_IN("'><style>", page$) + 1
  new_page$ = LEFT$(page$, left) + new_viewport$ + RIGHT$(page$, right)
  GW_SET_SKEY("page", page, new_page$)
FN.END

FN.DEF GW_PAGE_SCALE(page, zoom)
  script$ ="$(document).ready(function(){"
  script$+="$('body').css({transform:'scale("+STR$(zoom)+")'"
  script$+=",transformOrigin:'0 0',width:'"+INT$(100/zoom)+"%'});});"
  GW_INJECT_HTML(page, "<script>" + script$ + "</script>")
FN.END
